@@ -6,6 +6,12 @@
 #include "clad/Differentiator/ReverseModeVisitor.h"
 
 #include "clang/AST/Decl.h"
+#include "clang/AST/Expr.h"
+#include "clang/AST/OperationKinds.h"
+#include "clang/Basic/LLVM.h"
+
+#include <llvm/ADT/STLExtras.h>
+#include <llvm/ADT/SmallVector.h>
 
 using namespace clang;
 
@@ -38,6 +44,10 @@ void ErrorEstimationHandler::SetErrorEstimationModel(
   m_EstModel = estModel;
 }
 
+DeclRefExpr* ErrorEstimationHandler::BuildFinalErrorExpr() {
+  return m_RMV->BuildDeclRef(m_Params->back());
+}
+
 void ErrorEstimationHandler::BuildReturnErrorStmt() {
   // If we encountered any arithmetic expression in the return statement,
   // we must add its error to the final estimate.
@@ -48,14 +58,15 @@ void ErrorEstimationHandler::BuildReturnErrorStmt() {
     Expr* finExpr =
         m_EstModel->AssignError(StmtDiff(m_RetErrorExpr, flitr), "return_expr");
     m_RMV->addToCurrentBlock(
-        m_RMV->BuildOp(BO_AddAssign, m_FinalError, finExpr),
+        m_RMV->BuildOp(BO_AddAssign, BuildFinalErrorExpr(), finExpr),
         direction::forward);
   }
 }
 
 void ErrorEstimationHandler::AddErrorStmtToBlock(Expr* errorExpr,
                                                  bool addToTheFront) {
-  Stmt* errorStmt = m_RMV->BuildOp(BO_AddAssign, m_FinalError, errorExpr);
+  Expr* FinalError = BuildFinalErrorExpr();
+  Stmt* errorStmt = m_RMV->BuildOp(BO_AddAssign, FinalError, errorExpr);
   if (addToTheFront) {
     auto& block = m_RMV->getCurrentBlock(direction::reverse);
     block.insert(block.begin(), errorStmt);
@@ -108,10 +119,12 @@ void ErrorEstimationHandler::EmitNestedFunctionParamError(
     // // estimation.
     // if (utils::IsReferenceOrPointerType(fnDecl->getParamDecl(i)->getType()))
     //   continue;
+    auto* derefExpr = m_RMV->BuildOp(UO_Deref, ArgResult[i]);
     Expr* errorExpr = m_EstModel->AssignError(
-        {derivedCallArgs[i], m_RMV->Clone(ArgResult[i])},
+        {derivedCallArgs[i], derefExpr},
         fnDecl->getNameInfo().getAsString() + "_param_" + std::to_string(i));
-    Expr* errorStmt = m_RMV->BuildOp(BO_AddAssign, m_FinalError, errorExpr);
+    Expr* FinalError = BuildFinalErrorExpr();
+    Expr* errorStmt = m_RMV->BuildOp(BO_AddAssign, FinalError, errorExpr);
     m_ReverseErrorStmts.push_back(errorStmt);
   }
 }
@@ -178,7 +191,7 @@ void ErrorEstimationHandler::EmitFinalErrorStmts(
         auto* errorExpr = GetError(paramClone, m_RMV->m_Variables[decl],
                                    params[i]->getNameAsString());
         m_RMV->addToCurrentBlock(
-            m_RMV->BuildOp(BO_AddAssign, m_FinalError, errorExpr));
+            m_RMV->BuildOp(BO_AddAssign, BuildFinalErrorExpr(), errorExpr));
       } else {
         auto LdiffExpr = m_RMV->m_Variables[decl];
         Expr* size = getSizeExpr(decl);
@@ -197,7 +210,7 @@ void ErrorEstimationHandler::EmitFinalErrorStmts(
         // Build the loop to put in reverse mode.
         Expr* errorExpr = GetError(LRepl, Ldiff, params[i]->getNameAsString());
         Expr* finalAssignExpr =
-            m_RMV->BuildOp(BO_AddAssign, m_FinalError, errorExpr);
+            m_RMV->BuildOp(BO_AddAssign, BuildFinalErrorExpr(), errorExpr);
         Expr* conditionExpr = m_RMV->BuildOp(BO_LE, m_IdxExpr, size);
         Expr* incExpr = m_RMV->BuildOp(UO_PostInc, m_IdxExpr);
         Stmt* ArrayParamLoop = new (m_RMV->m_Context)
@@ -303,11 +316,6 @@ void ErrorEstimationHandler::ActAfterCreatingDerivedFnParams(
                                   /*AddToContext=*/false);
 }
 
-void ErrorEstimationHandler::ActBeforeCreatingDerivedFnBodyScope() {
-  // Reference to the final error statement
-  SetFinalErrorExpr(m_RMV->BuildDeclRef(m_Params->back()));
-}
-
 void ErrorEstimationHandler::ActOnEndOfDerivedFnBody() {
   // Since 'return' is not an assignment, add its error to _final_error
   // given it is not a DeclRefExpr.
@@ -339,9 +347,8 @@ void ErrorEstimationHandler::ActAfterProcessingArraySubscriptExpr(
         return;
 
       // We only need to know the size of independent arrays.
-      auto& indVars = m_RMV->m_IndependentVars;
-      auto* it = std::find(indVars.begin(), indVars.end(), VD);
-      if (it == indVars.end())
+      auto params = m_RMV->m_Derivative->parameters();
+      if (llvm::find(params, VD) == params.end())
         return;
 
       // Construct `var_size = max(var_size, idx);`
@@ -351,8 +358,8 @@ void ErrorEstimationHandler::ActAfterProcessingArraySubscriptExpr(
       idx =
           m_RMV->m_Sema.ImpCastExprToType(idx, size->getType(), CK_IntegralCast)
               .get();
-      llvm::SmallVector<clang::Expr*, 2> params{size, idx};
-      Expr* extendedSize = m_EstModel->GetFunctionCall("max", "std", params);
+      llvm::SmallVector<clang::Expr*, 2> args{size, idx};
+      Expr* extendedSize = m_EstModel->GetFunctionCall("max", "std", args);
       size = m_RMV->Clone(size);
       Stmt* updateSize = m_RMV->BuildOp(BO_Assign, size, extendedSize);
       m_RMV->addToCurrentBlock(updateSize, direction::reverse);
