@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -271,7 +271,7 @@ namespace ROOT {
       ::ROOT::Experimental::XRooFit::xRooNode::InteractiveObject *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::ROOT::Experimental::XRooFit::xRooNode::InteractiveObject >(nullptr);
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::Experimental::XRooFit::xRooNode::InteractiveObject", ::ROOT::Experimental::XRooFit::xRooNode::InteractiveObject::Class_Version(), "RooFit/xRooFit/xRooNode.h", 493,
+         instance("ROOT::Experimental::XRooFit::xRooNode::InteractiveObject", ::ROOT::Experimental::XRooFit::xRooNode::InteractiveObject::Class_Version(), "RooFit/xRooFit/xRooNode.h", 499,
                   typeid(::ROOT::Experimental::XRooFit::xRooNode::InteractiveObject), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &::ROOT::Experimental::XRooFit::xRooNode::InteractiveObject::Dictionary, isa_proxy, 4,
                   sizeof(::ROOT::Experimental::XRooFit::xRooNode::InteractiveObject) );
@@ -805,11 +805,6 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include/freetype2",
-"/usr/include/libxml2",
-"/usr/include",
-"/usr/include/freetype2",
-"/usr/include/libxml2",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
