@@ -42,7 +42,6 @@ Base class for plot-painters that provide GL rendering of various
 2D and 3D histograms, functions and parametric surfaces.
 */
 
-ClassImp(TGLPlotPainter);
 
 ////////////////////////////////////////////////////////////////////////////////
 ///TGLPlotPainter's ctor.
@@ -243,7 +242,7 @@ void TGLPlotPainter::PrintPlot()const
 
    Int_t gl2psFormat = GL2PS_EPS;
    Int_t gl2psSort   = GL2PS_BSP_SORT;
-   Int_t buffsize    = 0;
+   Int_t bufsize    = 0;
    Int_t state       = GL2PS_OVERFLOW;
    GLint gl2psoption = GL2PS_USE_CURRENT_VIEWPORT |
                        GL2PS_SILENT               |
@@ -252,11 +251,11 @@ void TGLPlotPainter::PrintPlot()const
                        0;
 
    while (state == GL2PS_OVERFLOW) {
-      buffsize += 1024*1024;
+      bufsize += 1024*1024;
       gl2psBeginPage ("ROOT Scene Graph", "ROOT", nullptr,
                       gl2psFormat, gl2psSort, gl2psoption,
                       GL_RGBA, 0, nullptr,0, 0, 0,
-                      buffsize, output, nullptr);
+                      bufsize, output, nullptr);
       DrawPlot();
       state = gl2psEndPage();
    }
@@ -619,7 +618,6 @@ Helper class for plot-painters holding information about axis
 ranges, numbers of bins and flags if certain axis is logarithmic.
 */
 
-ClassImp(TGLPlotCoordinates);
 
 ////////////////////////////////////////////////////////////////////////////////
 ///Constructor.
@@ -1420,7 +1418,6 @@ Bool_t FindAxisRange(TH2Poly *hist, Bool_t logZ, Rgl::Range_t &zRange)
 Used by plot-painters to determine the area of the plot that is cut away.
 */
 
-ClassImp(TGLBoxCut);
 
 ////////////////////////////////////////////////////////////////////////////////
 ///Constructor.
@@ -1692,7 +1689,6 @@ Bool_t TGLBoxCut::IsInCut(Double_t xMin, Double_t xMax, Double_t yMin, Double_t
 A slice of a TH3.
 */
 
-ClassImp(TGLTH3Slice);
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Constructor.
