@@ -1154,7 +1154,9 @@ std::string RooAbsCollection::contentsString() const
     retVal += ",";
   }
 
-  retVal.erase(retVal.end()-1);
+  if (!retVal.empty()) {
+    retVal.erase(retVal.end()-1);
+  }
 
   return retVal;
 }
@@ -1646,3 +1648,13 @@ void RooAbsCollection::throwAddTypedException(TClass *klass, RooAbsArg *arg)
    oocoutE(nullptr, InputArguments) << msg.str() << std::endl;
    throw std::invalid_argument(msg.str());
 }
+
+void RooAbsCollection::removeConstantParameters()
+{
+   RooArgSet constSet;
+   for (auto const *myarg : static_range_cast<RooRealVar *>(*this)) {
+      if (myarg->isConstant())
+         constSet.add(*myarg);
+   }
+   this->remove(constSet);
+}
